Trait HasOptionalBody

pub trait HasOptionalBody {
    type Body;

    // Required methods
    fn body(&self) -> Option<&Self::Body>;
    fn body_mut(&mut self) -> Option<&mut Self::Body>;
    fn set_body(&mut self, body: Self::Body);
    fn unset_body(&mut self);

    // Provided method
    fn has_body(&self) -> bool { ... }
}
This trait is implemented by types that have a distinct, but optional, body type.

Required Associated Types

type Body

This type is the particular body for the enclosing type.

Required Methods

fn body(&self) -> Option<&Self::Body>

fn body_mut(&mut self) -> Option<&mut Self::Body>

fn set_body(&mut self, body: Self::Body)

fn unset_body(&mut self)

Provided Methods

fn has_body(&self) -> bool

Implementors